(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{28:function(t,e,r){"use strict";r.r(e);var a=r(5),n=r.n(a),o=r(13),c=r.n(o),s=r(0),p=r(1),i=r(2),h=r(11),d=r(15),l=r(8),g=function(t){Object(p.a)(r,t);var e=Object(i.a)(r);function r(){var t;Object(s.a)(this,r);for(var a=arguments.length,n=new Array(a),o=0;o<a;o++)n[o]=arguments[o];return(t=e.call.apply(e,[this].concat(n))).render=function(){var e=[{eventName:"ready",callback:function(){console.log("Setting height ",h.a.setFrameHeight())}}];return Object(l.jsx)(d.a,{width:t.props.args.width+"px",height:t.props.args.height+"px",chartType:t.props.args.chartType,loader:Object(l.jsx)("div",{children:"Loading Chart"}),data:t.props.args.data,options:t.props.args.options,chartEvents:e,rootProps:{"data-testid":"1"}})},t}return r}(h.b),b=Object(h.c)(g);c.a.render(Object(l.jsx)(n.a.StrictMode,{children:Object(l.jsx)(b,{})}),document.getElementById("root"))}},[[28,1,2]]]);
//# sourceMappingURL=main.5ae4cced.chunk.js.map